summaryrefslogtreecommitdiffstats
path: root/generic/tclLoad.c
diff options
context:
space:
mode:
Diffstat (limited to 'generic/tclLoad.c')
-rw-r--r--generic/tclLoad.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/generic/tclLoad.c b/generic/tclLoad.c
index afad897..5f319d3 100644
--- a/generic/tclLoad.c
+++ b/generic/tclLoad.c
@@ -15,7 +15,7 @@
/*
* The following structure describes a library that has been loaded either
* dynamically (with the "load" command) or statically (as indicated by a call
* to Tcl_StaticPackage). All such libraries are linked together into a
* single list for the process. Library are never unloaded, until the
* application exits, when TclFinalizeLoad is called, and these structures are
* freed.
@@ -923,7 +923,7 @@ Tcl_UnloadObjCmd(
/*
*----------------------------------------------------------------------
*
- * Tcl_StaticPackage --
+ * Tcl_StaticLibrary --
*
* This function is invoked to indicate that a particular library has
* been linked statically with an application.
@@ -939,7 +939,7 @@ Tcl_UnloadObjCmd(
*/
void
-Tcl_StaticPackage(
+Tcl_StaticLibrary(
Tcl_Interp *interp, /* If not NULL, it means that the library has
* already been loaded into the given
* interpreter by calling the appropriate init
@@ -15,7 +15,7 @@
* The following structure describes a library that has been loaded either
* dynamically (with the "load" command) or statically (as indicated by a call
- * to Tcl_StaticPackage). All such libraries are linked together into a
+ * to Tcl_StaticLibrary). All such libraries are linked together into a
* single list for the process. Library are never unloaded, until the
* application exits, when TclFinalizeLoad is called, and these structures are